# Getting Around Pinguino IDE

# Main area

Pinguino IDE's interface is divided into, main editor area and panels tools.
Is possible maximize editor area hidding the panels tools with `F2` and `F3` or optionally with `Shift+F2` and hide toolbars too.
When a new blocks file is created a special tab called "Blocks" will appear, just drag and drope blocks over work area.

# Autocompleter

The autocompleter is a feature that allow write code a bit fast, is possible complete common Pinguino functions, Pinguino library calls, and some C snippets.
The autocompleter can be dissable unchecking in menu `Source` the option `Autocomplete code`.

# Contex Menus

In general, right click provides a contex menu with some usefull options.
The main editor has many options for code formatting, if current file is from default examples then you can restore all modifications.

Right click over tools tabs enable switching them.